#ifndef PLAYLIST_H
#define PLAYLIST_H

#include <QWidget>
#include <QTreeWidgetItem>
#include <playlists.h>
#include <QDialogButtonBox>
#include <QDialog>

namespace Ui {
    class Playlist;
}

class Playlist : public QWidget
{
    Q_OBJECT

public:
    explicit Playlist(QWidget *parent = 0);
    QStringList getPlaylists();
    void addToPlaylist(QString playlist, QString article);
    void setMode(QString mode);
    ~Playlist();

private slots:
    void on_treeWidget_itemClicked(QTreeWidgetItem *item, int column);
    void deleteArticle();
    void openArticle();

signals:
    void articleSelected(QTreeWidgetItem *item, int column);
    void playlistSelected(QList<QTreeWidgetItem *> items, int column);


private:
    Ui::Playlist *ui;
    QMap<QString, QString> *titles;
    Playlists *playlistlist;
    void updateList();
  //  QDialog *box;
    QTreeWidgetItem *clickedItem;
    int clickedColumn;

};

#endif // PLAYLIST_H
